@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@ class FilterActionMissingAccountDialogTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit FilterActionMissingAccountDialogTest(QObject *parent = Q_NULLPTR);
+    explicit FilterActionMissingAccountDialogTest(QObject *parent = nullptr);
     ~FilterActionMissingAccountDialogTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
