@@ -29,7 +29,7 @@ class FilterActionMissingSoundUrlDialog : public QDialog
 public:
     explicit FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent = nullptr);
     ~FilterActionMissingSoundUrlDialog();
-    QString soundUrl() const;
+    Q_REQUIRED_RESULT QString soundUrl() const;
 
 private:
     void readConfig();
